==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/helpers/AttributeAssertionFetcher.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Oct 6, 2011
 * Author: K. Stasiak <karol.m.stasiak@gmail.com>
 */
package de.fzj.unicore.ucc.helpers;

import java.net.MalformedURLException;
import java.security.cert.X509Certificate;
import java.util.Properties;

import javax.security.auth.x500.X500Principal;

import org.apache.log4j.Logger;

import de.fzj.unicore.ucc.util.VOAttributeFilter;

import eu.unicore.samly2.assertion.Assertion;
import eu.unicore.samly2.exceptions.SAMLParseException;

import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.AttributeNotFoundException;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UnsupportedSAMLException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.InvalidSignatureException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.InvocationException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.SAMLErrorResponseException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.SAMLVOQueryClient;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.SecuritySetupException;

/**
 * Helper class for fetching attribute assertions from VO server.
 * @author kstasiak
 */
public class AttributeAssertionFetcher {
	private static final Logger logger=Logger.getLogger(AttributeAssertionFetcher.class.getCanonicalName());

	private final VOConfiguration cfg;
	
	private final SAMLVOQueryClient client;

	/**
	 *
	 * @param cfg configuration for {@link SAMLVOQueryClient}
	 * @param voURL URL of VO server
	 * @param properties additional properties
	 * @throws SecuritySetupException
	 * @throws MalformedURLException
	 */
	public AttributeAssertionFetcher(VOConfiguration cfg, String voURL,
			Properties properties) throws SecuritySetupException, MalformedURLException {
		client = new SAMLVOQueryClient(voURL, cfg, properties);
		client.setDSigPolicy(false, true, null);
		this.cfg = cfg;
	}

	/**
	 * Fetches an attribute assertion from VO server.
	 * If the filter does not report that it allows all attributes
	 * (by returning true from {@link VOAttributeFilter#allowsEverything() allowsEverything()}),
	 * the attribute list is fetched from server, filtered and server is queried again for the list.
	 * @param scope the scope of attributes, VO and group
	 * @param attributeFilter attribute filter
	 * @return assertion containing attributes in given scope and accepted by given filter
	 * @throws SAMLErrorResponseException 
	 * @throws InvocationException 
	 * @throws InvalidSignatureException 
	 * @throws UnsupportedSAMLException 
	 * @throws SAMLParseException 
	 * @throws AttributeNotFoundException 
	 */
	public Assertion fetchAssertion(String scope, VOAttributeFilter attributeFilter) 
			throws SAMLErrorResponseException, AttributeNotFoundException, 
			SAMLParseException, UnsupportedSAMLException, InvalidSignatureException,
			InvocationException  {
		X509Certificate cert = cfg.getSecurityProperties().getPublicKey();
		String userDn = cert.getSubjectX500Principal().getName(X500Principal.RFC2253);
		logger.trace("User identity: " + userDn);

		Group ggroup = null;
		if (scope!=null) {
			ggroup = new Group(scope);
			logger.debug("Assuming group " + scope);
		} else
			logger.debug("Scope (group) was not selected, fetching attributes from all groups");
		
		Identity identity = new Identity(IdentityType.DN, userDn);

		Assertion a = client.getFilteredAssertion(identity, ggroup, true, attributeFilter);
		if(logger.isTraceEnabled()){
			logger.trace("Attribute assertion fetched:");
			logger.trace(a.getXML().toString());
		}
		return a;
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/helpers/AttributeAssertionFetcher.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Oct 6, 2011
 * Author: K. Stasiak <karol.m.stasiak@gmail.com>
 */
package de.fzj.unicore.ucc.helpers;

import java.net.MalformedURLException;

import org.apache.log4j.Logger;

import de.fzj.unicore.ucc.util.VOAttributeFilter;

import eu.emi.security.authn.x509.impl.X500NameUtils;
import eu.unicore.samly2.assertion.Assertion;
import eu.unicore.samly2.exceptions.SAMLParseException;
import eu.unicore.util.httpclient.IClientConfiguration;

import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.AttributeNotFoundException;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UnsupportedSAMLException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.InvalidSignatureException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.InvocationException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.SAMLErrorResponseException;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.SAMLVOQueryClient;
import pl.edu.icm.unicore.uvos.wsclient.samlapi.SecuritySetupException;

/**
 * Helper class for fetching attribute assertions from VO server.
 * @author kstasiak
 */
public class AttributeAssertionFetcher {
	private static final Logger logger=Logger.getLogger(AttributeAssertionFetcher.class.getCanonicalName());

	private final IClientConfiguration cfg;
	
	private final SAMLVOQueryClient client;

	/**
	 * @param cfg configuration for {@link SAMLVOQueryClient}
	 * @param voURL URL of VO server
	 * @throws SecuritySetupException
	 * @throws MalformedURLException
	 */
	public AttributeAssertionFetcher(IClientConfiguration cfg, String voURL) throws SecuritySetupException, MalformedURLException {
		client = new SAMLVOQueryClient(voURL, cfg);
		//here we use a normal validator - we don't have to really validate our own assertion
		// - server will check it carefully as it relies on the attributes.
		client.setDSigPolicy(false, true, null, cfg.getValidator());
		this.cfg = cfg;
	}

	/**
	 * Fetches an attribute assertion from VO server.
	 * If the filter does not report that it allows all attributes
	 * (by returning true from {@link VOAttributeFilter#allowsEverything()}),
	 * the attribute list is fetched from server, filtered and server is queried again for the list.
	 * @param scope the scope of attributes, VO and group
	 * @param attributeFilter attribute filter
	 * @return assertion containing attributes in given scope and accepted by given filter
	 * @throws SAMLErrorResponseException 
	 * @throws InvocationException 
	 * @throws InvalidSignatureException 
	 * @throws UnsupportedSAMLException 
	 * @throws SAMLParseException 
	 * @throws AttributeNotFoundException 
	 */
	public Assertion fetchAssertion(String scope, VOAttributeFilter attributeFilter) 
			throws SAMLErrorResponseException, AttributeNotFoundException, 
			SAMLParseException, UnsupportedSAMLException, InvalidSignatureException,
			InvocationException  {
		String userDn = cfg.getCredential().getSubjectName();
		logger.trace("User identity: " + X500NameUtils.getReadableForm(userDn));

		Group ggroup = null;
		if (scope!=null) {
			ggroup = new Group(scope);
			logger.debug("Assuming group " + scope);
		} else
			logger.debug("Scope (group) was not selected, fetching attributes from all groups");
		
		Identity identity = new Identity(IdentityType.DN, userDn);

		Assertion a = client.getFilteredAssertion(identity, ggroup, true, attributeFilter);
		if(logger.isTraceEnabled()){
			logger.trace("Attribute assertion fetched:");
			logger.trace(a.getXML().toString());
		}
		return a;
	}
}
